/****************************************************************************
 *  Copyright (C) 2009-2010 by Martin Engelmann, murphi.oss@googlemail.com  *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or           *
 *  modify it under the terms of the GNU General Public License as          *
 *  published by the Free Software Foundation; either version 2 of          *
 *  the License or (at your option) any later version.                      *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License       *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>    *
 ****************************************************************************/

#include "ingredient.h"


class IngredientPrivate
{
public:
    IngredientPrivate()
            : amount(0.) {
    }

    double  amount;
    QString unit;
    QString name;
};

Ingredient::Ingredient()
        : d(new IngredientPrivate())
{
}

Ingredient::Ingredient(double amount, const QString& unit, const QString& name)
        : d(new IngredientPrivate())
{
    d->amount = amount;
    d->unit = unit;
    d->name = name;
}

Ingredient::Ingredient(const Ingredient& rhs)
        : d(new IngredientPrivate(*(rhs.d)))
{
}

Ingredient::~Ingredient()
{
    delete d;
}

Ingredient& Ingredient::operator=(const Ingredient & rhs)
{
    if (this == &rhs) return *this;

    delete d;
    d = new IngredientPrivate(*(rhs.d));
    return *this;
}

bool Ingredient::operator==(const Ingredient& rhs) const
{
    return  d->amount   ==  rhs.d->amount   &&
            d->unit     ==  rhs.d->unit     &&
            d->name     ==  rhs.d->name;
}

bool Ingredient::operator!=(const Ingredient& rhs) const
{
    return !(*this == rhs);
}

double Ingredient::amount() const
{
    return d->amount;
}


void Ingredient::setAmount(double theValue)
{
    if (d->amount != theValue) {
        d->amount = theValue;
    }
}

QString Ingredient::unit() const
{
    return d->unit;
}


void Ingredient::setUnit(const QString& theValue)
{
    if (d->unit != theValue) {
        d->unit = theValue;
    }
}

QString Ingredient::name() const
{
    return d->name;
}

void Ingredient::setName(const QString& theValue)
{
    if (d->name != theValue) {
        d->name = theValue;
    }
}

