/****************************************************************************
 *  Copyright (C) 2009-2010 by Martin Engelmann, murphi.oss@googlemail.com  *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or           *
 *  modify it under the terms of the GNU General Public License as          *
 *  published by the Free Software Foundation; either version 2 of          *
 *  the License or (at your option) any later version.                      *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License       *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>    *
 ****************************************************************************/

#ifndef RECIPE_H
#define RECIPE_H

// Qt includes
#include <QString>


// local includes
#include "ingredient.h"

class RecipePrivate;

class Recipe
{
public:
    Recipe();
    explicit Recipe(const QString& title);
    Recipe(const Recipe& rhs);
    ~Recipe();

    Recipe& operator=(const Recipe& rhs);

    QString title() const;
    void setTitle(const QString& theValue);

    QString author() const;
    void setAuthor(const QString& theValue);

    QString blurb() const;
    void setBlurb(const QString& theValue);

    QString effort() const;
    void setEffort(const QString& theValue);

    QString genre() const;
    void setGenre(const QString& theValue);

    QString preparationTime() const;
    void setPreparationTime(const QString& theValue);

    QString source() const;
    void setSource(const QString& theValue);

    QString yield() const;
    void setYield(const QString& theValue);

    int numberOfIngredients() const;
    Ingredient ingredient(int index) const;
    void addIngredient(const Ingredient& theValue);
    void addIngredient(double amount, const QString& unit, const QString& name);
    void setIngredient(int index, const Ingredient& theValue);

    int numberOfSteps() const;
    QString step(int index) const;
    void addStep(const QString & theValue);
    void setStep(int index, const QString & theValue);


private:
    RecipePrivate* d;

};

#endif
