/****************************************************************************
 *  Copyright (C) 2009-2010 by Martin Engelmann, murphi.oss@googlemail.com  *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or           *
 *  modify it under the terms of the GNU General Public License as          *
 *  published by the Free Software Foundation; either version 2 of          *
 *  the License or (at your option) any later version.                      *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License       *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>    *
 ****************************************************************************/

#include "recipedisplaywidget.h"

// Qt includes
#include <QtGui/QHBoxLayout>

// KDE includes
#include <ktextbrowser.h>
#include <klocale.h>

// Local includes
#include "recipe.h"
#include "recipeeditdialog.h"


RecipeDisplayWidget::RecipeDisplayWidget(QWidget* parent)
        : QWidget(parent),
        m_browser(new KTextBrowser()),
        m_recipe(0)
{
    QHBoxLayout* layout = new QHBoxLayout(this);
    layout->addWidget(m_browser);
}


RecipeDisplayWidget::~RecipeDisplayWidget()
{
    delete m_recipe;
}

void RecipeDisplayWidget::setRecipe(const Recipe& recipe)
{
    delete m_recipe;
    m_recipe = new Recipe(recipe);
    displayRecipe();
    emit modified(false);
}

const Recipe* RecipeDisplayWidget::recipe() const
{
    return m_recipe;
}

void RecipeDisplayWidget::slotEdit()
{
    RecipeEditDialog dlg;
    dlg.setRecipe(*m_recipe);

    if (dlg.exec() == QDialog::Accepted && dlg.isWindowModified()) {
        setRecipe(dlg.recipe());
        emit modified(true);
    }
}

void RecipeDisplayWidget::displayRecipe()
{
    if (!m_recipe) return;

    QString html;
    html += i18n("<h1>%1</h1>", m_recipe->title());

    addToDisplay(html, i18n("<p>%1</p>"), m_recipe->blurb());
    addToDisplay(html, i18n("<p>Author: %1</p>"), m_recipe->author());
    addToDisplay(html, i18n("<p>Effort: %1</p>"), m_recipe->effort());
    addToDisplay(html, i18n("<p>Genre: %1</p>"), m_recipe->genre());
    addToDisplay(html, i18n("<p>Preparation time: %1</p>"), m_recipe->preparationTime());
    addToDisplay(html, i18n("<p>Source: %1</p>"), m_recipe->source());
    addToDisplay(html, i18n("<p>Yield: %1</p>"), m_recipe->yield());

    html += i18n("<h2>Ingredients</h2>");
    html += "<ul>";
    for (int i = 0; i < m_recipe->numberOfIngredients(); ++i) {
        const Ingredient ingredient = m_recipe->ingredient(i);
        html += i18n("<li>%1 %2 %3</li>", ingredient.amount(),
                     ingredient.unit(), ingredient.name());
    }
    html += "</ul>";
    html += i18n("<h2>Steps</h2>");
    html += "<ol>";
    for (int i = 0; i < m_recipe->numberOfSteps(); ++i) {
        html += i18n("<li>%1</li>", m_recipe->step(i));
    }
    html += "</ol>";

    m_browser->setHtml(html);
}

void RecipeDisplayWidget::addToDisplay(QString& html, const QString& format, const QString& value) const
{
    if (!value.isEmpty()) {
        html += format.arg(value);
    }
}


#include "recipedisplaywidget.moc"
