/****************************************************************************
 *  Copyright (C) 2009-2010 by Martin Engelmann, murphi.oss@googlemail.com  *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or           *
 *  modify it under the terms of the GNU General Public License as          *
 *  published by the Free Software Foundation; either version 2 of          *
 *  the License or (at your option) any later version.                      *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License       *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>    *
 ****************************************************************************/

#include "recipeeditdialog.h"

#include <kmessagebox.h>
#include <kcomponentdata.h>
#include <kaction.h>
#include <kactioncollection.h>
#include <klocale.h>

#include "recipe.h"
#include "recipeeditdialogpage.h"
#include "recipeeditdialogpage_general.h"
#include "recipeeditdialogpage_ingredients.h"
#include "recipeeditdialogpage_steps.h"

RecipeEditDialog::RecipeEditDialog(QWidget *parent)
        : KPageDialog(parent),
        m_actions(new KActionCollection(this))
{
    setInitialSize(QSize(600, 400));

    setupActions();
    setupPages();
}


RecipeEditDialog::~RecipeEditDialog()
{
}


void RecipeEditDialog::setRecipe(const Recipe& recipe)
{
    foreach(KPageWidgetItem* page, m_pages) {
        qobject_cast<RecipeEditDialogPage*>(page->widget())->readFromRecipe(recipe);
    }
    setWindowModified(false);
}


Recipe RecipeEditDialog::recipe() const
{
    Recipe result;
    foreach(KPageWidgetItem* page, m_pages) {
        qobject_cast<RecipeEditDialogPage*>(page->widget())->writeToRecipe(result);
    }
    return result;
}

void RecipeEditDialog::slotUpdateWindowTitle(const QString & title)
{
    setWindowTitle(i18nc("@title:window", "%1[*] - %2",
                         title, KGlobal::mainComponent().componentName()));
}

void RecipeEditDialog::slotRecipeChanged()
{
    setWindowModified(true);
    emit changed();
}

void RecipeEditDialog::slotNextPage()
{
    int newPageIndex = m_pages.indexOf(currentPage()) + 1;
    if (newPageIndex >= m_pages.size()) newPageIndex = 0;

    setCurrentPage(m_pages.at(newPageIndex));
}

void RecipeEditDialog::slotPreviousPage()
{
    int newPageIndex = m_pages.indexOf(currentPage()) - 1;
    if (newPageIndex < 0) newPageIndex = m_pages.size() - 1;

    setCurrentPage(m_pages.at(newPageIndex));
}

void RecipeEditDialog::setupActions()
{
    KAction* nextPage = m_actions->addAction(KStandardAction::Next, this, SLOT(slotNextPage()));
    nextPage->setShortcut(KShortcut(Qt::Key_PageDown, Qt::CTRL + Qt::Key_Tab));

    KAction* prevPage = m_actions->addAction(KStandardAction::Prior, this, SLOT(slotPreviousPage()));
    prevPage->setShortcut(KShortcut(Qt::Key_PageUp, Qt::SHIFT + Qt::CTRL + Qt::Key_Tab));
}

void RecipeEditDialog::setupPages()
{
    KPageWidgetItem* general = new KPageWidgetItem(
        new RecipeEditDialogPageGeneral(), i18nc("@item Page in KPageDialog", "General"));
    general->setHeader(general->widget()->windowTitle());
    general->setIcon(KIcon("kookie"));
    connect(general->widget(), SIGNAL(changed()), this, SLOT(slotRecipeChanged()));
    connect(general->widget(), SIGNAL(titleChanged(QString)),
            this, SLOT(slotUpdateWindowTitle(QString)));
    m_pages << general;

    KPageWidgetItem* ingredients = new KPageWidgetItem(
        new RecipeEditDialogPageIngredients(), i18nc("@item Page in KPageDialog", "Ingredients"));
    ingredients->setHeader(ingredients->widget()->windowTitle());
    ingredients->setIcon(KIcon("kookie-ingredients"));
    connect(ingredients->widget(), SIGNAL(changed()), this, SLOT(slotRecipeChanged()));
    m_pages << ingredients;

    KPageWidgetItem* steps = new KPageWidgetItem(
        new RecipeEditDialogPageSteps(), i18nc("@item Page in KPageDialog", "Steps"));
    steps->setHeader(steps->widget()->windowTitle());
    steps->setIcon(KIcon("kookie-pot"));
    connect(steps->widget(), SIGNAL(changed()), this, SLOT(slotRecipeChanged()));
    m_pages << steps;


    foreach(KPageWidgetItem* page, m_pages) {
        addPage(page);
        m_actions->addAssociatedWidget(page->widget());
    }
}

#include "recipeeditdialog.moc"
