/****************************************************************************
 *  Copyright (C) 2009-2010 by Martin Engelmann, murphi.oss@googlemail.com  *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or           *
 *  modify it under the terms of the GNU General Public License as          *
 *  published by the Free Software Foundation; either version 2 of          *
 *  the License or (at your option) any later version.                      *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License       *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>    *
 ****************************************************************************/

#include "recipeeditdialogpage_steps.h"

#include "ui_RecipeEditDialogPage_steps.h"
#include "recipe.h"

RecipeEditDialogPageSteps::RecipeEditDialogPageSteps(QWidget* parent)
        : RecipeEditDialogPage(parent),
        ui(new Ui::RecipeEditDialogPage_steps())
{
    ui->setupUi(this);

    connect(ui->teSteps, SIGNAL(textChanged()),
            this, SIGNAL(changed()));
}

RecipeEditDialogPageSteps::~RecipeEditDialogPageSteps()
{
    delete ui;
}

void RecipeEditDialogPageSteps::readFromRecipe(const Recipe& recipe)
{
    QString steps;
    for (int step = 0; step < recipe.numberOfSteps(); ++step) {
        steps += QString("%0. %1\n\n").arg(step + 1).arg(recipe.step(step));
    }
    ui->teSteps->setText(steps);
}

void RecipeEditDialogPageSteps::writeToRecipe(Recipe& recipe) const
{
    QStringList steps(ui->teSteps->toPlainText().split("\n\n", QString::SkipEmptyParts));
    QRegExp leadingNumber("^\\d+\\.\\s*");
    foreach(QString step, steps) {  //krazy:exclude=foreach
        step.remove(leadingNumber);
        recipe.addStep(step);
    }
}

#include "recipeeditdialogpage_steps.moc"
